"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.APISchema = void 0;
function _chalk() {
  const data = _interopRequireDefault(require("chalk"));
  _chalk = function () {
    return data;
  };
  return data;
}
function _componentId() {
  const data = require("@teambit/component-id");
  _componentId = function () {
    return data;
  };
  return data;
}
function _schemas() {
  const data = require("./schemas");
  _schemas = function () {
    return data;
  };
  return data;
}
function _schemaNode() {
  const data = require("./schema-node");
  _schemaNode = function () {
    return data;
  };
  return data;
}
function _tag() {
  const data = require("./schemas/docs/tag");
  _tag = function () {
    return data;
  };
  return data;
}
function _schemaRegistry() {
  const data = require("./schema-registry");
  _schemaRegistry = function () {
    return data;
  };
  return data;
}
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
class APISchema extends _schemaNode().SchemaNode {
  // index

  constructor(location, module, internals, componentId, taggedModuleExports = []) {
    super();
    this.location = location;
    this.module = module;
    this.internals = internals;
    this.componentId = componentId;
    taggedModuleExports = taggedModuleExports.length && taggedModuleExports || this.listTaggedExports(module);
    this.taggedModuleExports = taggedModuleExports;
  }
  listTaggedExports(module) {
    if (!module) return [];
    return module.exports.filter(e => {
      if (_schemas().ExportSchema.isExportSchema(e)) {
        return e.exportNode.doc?.hasTag(_tag().TagName.exports) || e.doc?.hasTag(_tag().TagName.exports);
      }
      return e.doc?.hasTag(_tag().TagName.exports);
    }).map(e => {
      if (_schemas().ExportSchema.isExportSchema(e)) {
        return e.exportNode;
      }
      return e;
    });
  }
  toString() {
    return JSON.stringify(this.module.exports.map(exp => exp.toObject()), undefined, 2);
  }
  toStringPerType() {
    const title = _chalk().default.inverse(`API Schema of ${this.componentId.toString()}\n`);
    const exportGroups = this.module.exports.reduce((acc, exp) => {
      const node = _schemas().ExportSchema.isExportSchema(exp) ? exp.exportNode : exp;
      const displayName = node.displaySchemaName;
      (acc[displayName] = acc[displayName] || []).push(exp);
      return acc;
    }, {});
    const sortedDisplayNames = Object.keys(exportGroups).sort();
    if (sortedDisplayNames.length === 0) {
      return title;
    }
    const sections = sortedDisplayNames.map(displayName => {
      const exports = exportGroups[displayName];
      const sectionBody = exports.map(c => c.toString({
        color: true
      })).join('\n');
      return `${_chalk().default.green.bold(displayName)}\n${sectionBody}`;
    });
    return title + sections.join('\n\n') + '\n\n';
  }
  toFullSignature(options = {
    showDocs: true
  }) {
    const title = `API Schema of ${this.componentId.toString()}\n\n`;
    const exportGroups = {};
    for (const exp of this.module.exports) {
      const node = _schemas().ExportSchema.isExportSchema(exp) ? exp.exportNode : exp;
      const constructorName = node.constructor.name;
      if (!exportGroups[constructorName]) {
        exportGroups[constructorName] = [];
      }
      exportGroups[constructorName].push(exp);
    }
    let output = options.showTitles ? title : '';
    for (const [sectionName, exports] of Object.entries(exportGroups)) {
      const readableSectionName = options.showTitles ? this.getReadableSectionName(sectionName) : '';
      output += `${readableSectionName}\n\n`;
      const sectionBody = exports.map(exp => exp.toFullSignature(options)).join('\n\n');
      output += `${sectionBody}\n\n`;
    }
    return output.trim();
  }
  getReadableSectionName(constructorName) {
    const sectionNameMap = {
      ModuleSchema: 'Namespaces',
      ClassSchema: 'Classes',
      InterfaceSchema: 'Interfaces',
      FunctionLikeSchema: 'Functions',
      VariableLikeSchema: 'Variables',
      TypeSchema: 'Types',
      EnumSchema: 'Enums',
      TypeRefSchema: 'Type References',
      UnresolvedSchema: 'Unresolved',
      ReactSchema: 'React Components'
    };
    return sectionNameMap[constructorName] || constructorName;
  }
  listSignatures() {
    return this.module.exports.map(exp => exp.signature);
  }
  toObject() {
    return {
      ...super.toObject(),
      module: this.module.toObject(),
      internals: this.internals.map(i => i.toObject()),
      componentId: this.componentId.toObject(),
      taggedModuleExports: this.taggedModuleExports.map(e => e.toObject())
    };
  }
  static fromObject(obj) {
    const location = obj.location;
    const module = _schemas().ModuleSchema.fromObject(obj.module);
    const internals = (obj.internals || []).map(i => _schemas().ModuleSchema.fromObject(i));
    const componentId = _componentId().ComponentID.fromObject(obj.componentId);
    const taggedModuleExports = (obj.taggedModuleExports || []).map(e => _schemaRegistry().SchemaRegistry.fromObject(e));
    return new APISchema(location, module, internals, componentId, taggedModuleExports);
  }
  static empty(componentId) {
    return new APISchema({
      filePath: '',
      line: 0,
      character: 0
    }, new (_schemas().ModuleSchema)({
      filePath: '',
      line: 0,
      character: 0
    }, [], []), [], componentId);
  }
}
exports.APISchema = APISchema;

//# sourceMappingURL=api-schema.js.map