import { DocSchema } from './schemas';
export interface ISchemaNode {
    __schema: string;
    location: SchemaLocation;
    doc?: DocSchema;
    signature?: string;
    name?: string;
    toObject(): Record<string, any>;
    toString(options?: {
        color?: boolean;
    }): string;
    toFullSignature(options?: {
        showDocs?: boolean;
    }): string;
    getNodes(): SchemaNode[];
    findNode(predicate: (node: SchemaNode) => boolean, visitedNodes?: Set<SchemaNode>): SchemaNode | undefined;
    getAllNodesRecursively(visitedNodes?: Set<SchemaNode>): SchemaNode[];
    displaySchemaName: string;
}
/**
 * a convenient abstract class for all schema to extend.
 * the reason for having it as an abstract class and not an interface, for now, is mostly for the `__schema` prop.
 * this way it won't need to be implemented in each one of the subclasses.
 */
export declare abstract class SchemaNode implements ISchemaNode {
    readonly __schema: string;
    readonly displaySchemaName: string;
    abstract readonly location: SchemaLocation;
    readonly doc?: DocSchema;
    readonly signature?: string;
    readonly name?: string;
    static fromObject(obj: Record<string, any>): SchemaNode;
    toObject(): Record<string, any>;
    abstract toString(options?: {
        color?: boolean;
    }): string;
    abstract toFullSignature(options?: {
        showDocs?: boolean;
    }): string;
    getNodes(): SchemaNode[];
    getAllNodesRecursively(visitedNodes?: Set<SchemaNode>): SchemaNode[];
    findNode(predicate: (node: SchemaNode) => boolean, visitedNodes?: Set<SchemaNode>): SchemaNode | undefined;
}
export type SchemaLocation = {
    /**
     * file-path relative to the component root-dir. normalized to Linux.
     */
    filePath: string;
    line: number;
    character: number;
};
