"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SchemaNode = void 0;
function _lodash() {
  const data = require("lodash");
  _lodash = function () {
    return data;
  };
  return data;
}
function _pluralize() {
  const data = _interopRequireDefault(require("pluralize"));
  _pluralize = function () {
    return data;
  };
  return data;
}
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
/**
 * a convenient abstract class for all schema to extend.
 * the reason for having it as an abstract class and not an interface, for now, is mostly for the `__schema` prop.
 * this way it won't need to be implemented in each one of the subclasses.
 */
class SchemaNode {
  __schema = this.constructor.name;
  displaySchemaName = (0, _pluralize().default)(this.constructor.name.replace(/Schema$/, '').replace(/([A-Z])/g, ' $1').trim());
  // eslint-disable-next-line @typescript-eslint/no-unused-vars
  static fromObject(obj) {
    throw new Error(`Method 'fromObject' not implemented in subclass.`);
  }
  toObject() {
    return (0, _lodash().pickBy)({
      __schema: this.__schema,
      location: this.location,
      doc: this.doc ? this.doc.toObject() : undefined,
      signature: this.signature,
      name: this.name
    }, v => v !== undefined);
  }
  getNodes() {
    return [this];
  }
  getAllNodesRecursively(visitedNodes = new Set()) {
    if (visitedNodes.has(this)) {
      return [];
    }
    visitedNodes.add(this);
    const nodes = this.getNodes();
    return [this, ...nodes.flatMap(node => node.getAllNodesRecursively(visitedNodes))];
  }
  findNode(predicate, visitedNodes = new Set()) {
    if (predicate(this)) return this;
    if (visitedNodes.has(this)) return undefined;
    visitedNodes.add(this);
    for (const child of this.getNodes()) {
      const foundNode = child.findNode(predicate, visitedNodes);
      if (foundNode) return foundNode;
    }
    return undefined;
  }
}
exports.SchemaNode = SchemaNode;

//# sourceMappingURL=schema-node.js.map