"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SchemaRegistry = void 0;
function _unknownSchemaFactory() {
  const data = require("./unknown-schema-factory");
  _unknownSchemaFactory = function () {
    return data;
  };
  return data;
}
class SchemaRegistry {
  static instance = new SchemaRegistry();
  _getSchemas = [];
  constructor() {
    this._schemas = {};
  }
  static registerGetSchemas(getSchemas) {
    this.instance._getSchemas.push(getSchemas);
  }

  /**
   * @deprecated use registerGetSchemas instead
   * registerGetSchemas is better for performance as it lazy-loads the schemas.
   */
  static register(schema) {
    if (this.instance._schemas[schema.name]) return;
    this.instance._schemas[schema.name] = schema;
  }
  static schemas() {
    // this happens only once. as soon as the function is called, it registers all the schemas.
    this.instance._getSchemas.forEach(getSchemas => {
      const schemas = getSchemas();
      schemas.forEach(schema => {
        if (this.instance._schemas[schema.name]) return;
        this.instance._schemas[schema.name] = schema;
      });
    });
    this.instance._getSchemas = [];
    return this.instance._schemas;
  }
  static fromObject(obj) {
    if (!obj.__schema) {
      throw new Error(`fatal: "__schema" is missing, make sure the transformer is set on SchemaNode type`);
    }
    const schemas = this.schemas();
    const SchemaClass = schemas[obj.__schema];
    if (!SchemaClass) {
      // for backward and forward compatibility, to not break the users, it's better to return an unknown schema than throwing.
      return _unknownSchemaFactory().UnknownSchemaFactory.create(obj.location || {
        path: '',
        line: 0,
        character: 0
      }, obj.__schema, obj);
    }
    return SchemaClass.fromObject(obj);
  }
}
exports.SchemaRegistry = SchemaRegistry;

//# sourceMappingURL=schema-registry.js.map