"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ClassSchema = void 0;
function _chalk() {
  const data = _interopRequireDefault(require("chalk"));
  _chalk = function () {
    return data;
  };
  return data;
}
function _schemaNode() {
  const data = require("../schema-node");
  _schemaNode = function () {
    return data;
  };
  return data;
}
function _docs() {
  const data = require("./docs");
  _docs = function () {
    return data;
  };
  return data;
}
function _expressionWithArguments() {
  const data = require("./expression-with-arguments");
  _expressionWithArguments = function () {
    return data;
  };
  return data;
}
function _schemaRegistry() {
  const data = require("../schema-registry");
  _schemaRegistry = function () {
    return data;
  };
  return data;
}
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
class ClassSchema extends _schemaNode().SchemaNode {
  constructor(name, members, location, signature, doc, typeParams, extendsNodes, implementNodes, decorators) {
    super();
    this.name = name;
    this.location = location;
    this.signature = signature;
    this.typeParams = typeParams;
    this.extendsNodes = extendsNodes;
    this.implementNodes = implementNodes;
    this.decorators = decorators;
    this.members = members;
    this.doc = doc;
  }
  getNodes() {
    return this.members;
  }
  toString(options) {
    const boldUnderline = options?.color ? _chalk().default.bold.underline : str => str;
    const membersStr = this.members.map(m => `* ${m.toString(options)}`).join('\n');
    const decoratorsStr = this.decorators?.map(decorator => decorator.toString(options)).join('\n');
    return `${this.decorators ? `${decoratorsStr}\n` : ''}${boldUnderline(this.name)}\n${membersStr}`;
  }
  toFullSignature(options) {
    let result = '';
    if (options?.showDocs && this.doc) {
      result += `${this.doc.toFullSignature()}\n`;
    }
    const decoratorsStr = this.decorators?.map(decorator => decorator.toFullSignature(options)).join('\n');
    if (decoratorsStr) {
      result += `${decoratorsStr}\n`;
    }
    let classDeclaration = `class ${this.name}`;
    if (this.typeParams && this.typeParams.length > 0) {
      classDeclaration += `<${this.typeParams.join(', ')}>`;
    }
    if (this.extendsNodes && this.extendsNodes.length > 0) {
      const extendsStr = this.extendsNodes.map(node => node.toFullSignature(options)).join(', ');
      classDeclaration += ` extends ${extendsStr}`;
    }
    if (this.implementNodes && this.implementNodes.length > 0) {
      const implementsStr = this.implementNodes.map(node => node.toFullSignature(options)).join(', ');
      classDeclaration += ` implements ${implementsStr}`;
    }
    result += `${classDeclaration} {\n`;
    const membersStr = this.members.map(member => {
      const memberStr = member.toFullSignature(options);
      return memberStr.split('\n').map(line => `  ${line}`).join('\n');
    }).join('\n');
    result += `${membersStr}\n`;
    result += `}`;
    return result;
  }
  toObject() {
    return {
      ...super.toObject(),
      name: this.name,
      members: this.members.map(member => member.toObject()),
      doc: this.doc?.toObject(),
      signature: this.signature,
      typeParams: this.typeParams,
      extendsNodes: this.extendsNodes?.map(node => node.toObject()),
      implementNodes: this.implementNodes?.map(node => node.toObject()),
      decorators: this.decorators?.map(decorator => decorator.toObject())
    };
  }
  static fromObject(obj) {
    const name = obj.name;
    const members = obj.members.map(member => _schemaRegistry().SchemaRegistry.fromObject(member));
    const location = obj.location;
    const signature = obj.signature;
    const doc = obj.doc ? _docs().DocSchema.fromObject(obj.doc) : undefined;
    const typeParams = obj.typeParams;
    const extendsNodes = obj.extendsNodes?.map(node => _expressionWithArguments().ExpressionWithTypeArgumentsSchema.fromObject(node));
    const implementNodes = obj.implementNodes?.map(node => _expressionWithArguments().ExpressionWithTypeArgumentsSchema.fromObject(node));
    const decorators = obj.decorators?.map(decorator => _schemaRegistry().SchemaRegistry.fromObject(decorator));
    return new ClassSchema(name, members, location, signature, doc, typeParams, extendsNodes, implementNodes, decorators);
  }
  static fromSchema(node, memberTransformer = _node => _node) {
    return new ClassSchema(node.name, node.members.map(memberTransformer), node.location, node.signature, node.doc, node.typeParams, node.extendsNodes, node.implementNodes, node.decorators);
  }
}
exports.ClassSchema = ClassSchema;

//# sourceMappingURL=class.js.map