"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.DocSchema = void 0;
function _schemaNode() {
  const data = require("../../schema-node");
  _schemaNode = function () {
    return data;
  };
  return data;
}
function _schemaRegistry() {
  const data = require("../../schema-registry");
  _schemaRegistry = function () {
    return data;
  };
  return data;
}
class DocSchema extends _schemaNode().SchemaNode {
  constructor(location, raw, comment, tags) {
    super();
    this.location = location;
    this.raw = raw;
    this.comment = comment;
    this.tags = tags;
  }
  toString() {
    const comment = this.comment ? `${this.comment}\n` : '';
    const tags = this.tags ? this.tags.map(tag => tag.toString()).join('\n') : '';
    return `${comment}${tags}`;
  }
  toFullSignature() {
    const lines = [];
    if (this.comment) {
      lines.push(...this.comment.split('\n').map(line => ` * ${line.trim()}`));
    }
    if (this.tags && this.tags.length > 0) {
      for (const tag of this.tags) {
        lines.push(` * ${tag.toString().trim()}`);
      }
    }
    if (lines.length === 0) {
      return '';
    }
    return `/**\n${lines.join('\n')}\n */`;
  }
  hasTag(tagName) {
    return Boolean(this.findTag(tagName));
  }
  findTag(tagName) {
    return this.tags?.find(tag => tag.tagName === tagName);
  }
  toObject() {
    return {
      __schema: this.__schema,
      name: this.name,
      location: this.location,
      signature: this.signature,
      raw: this.raw,
      comment: this.comment,
      tags: this.tags ? this.tags.map(tag => tag.toObject()) : undefined
    };
  }
  static fromObject(obj) {
    const location = obj.location;
    const tags = obj.tags ? obj.tags.map(tag => _schemaRegistry().SchemaRegistry.fromObject(tag)) : undefined;
    return new DocSchema(location, obj.raw, obj.comment, tags);
  }
}
exports.DocSchema = DocSchema;

//# sourceMappingURL=doc.js.map