"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ReturnTagSchema = void 0;
function _schemaRegistry() {
  const data = require("../../schema-registry");
  _schemaRegistry = function () {
    return data;
  };
  return data;
}
function _tag() {
  const data = require("./tag");
  _tag = function () {
    return data;
  };
  return data;
}
/**
 * e.g. `@return {string} some comment`
 */
class ReturnTagSchema extends _tag().TagSchema {
  constructor(location, comment, type) {
    super(location, _tag().TagName.return, comment);
    this.location = location;
    this.comment = comment;
    this.type = type;
  }
  toString() {
    const comment = this.comment ? ` ${this.comment}` : '';
    return `@${this.tagName}${comment}`;
  }
  toFullSignature(options) {
    const typeStr = this.type ? ` {${this.type.toFullSignature(options)}}` : '';
    const comment = this.comment ? ` ${this.comment}` : '';
    return `@${this.tagName}${typeStr}${comment}`;
  }
  toObject() {
    return {
      ...super.toObject(),
      type: this.type?.toObject()
    };
  }
  static fromObject(obj) {
    const location = obj.location;
    const comment = obj.comment;
    const type = obj.type ? _schemaRegistry().SchemaRegistry.fromObject(obj.type) : undefined;
    return new ReturnTagSchema(location, comment, type);
  }
}
exports.ReturnTagSchema = ReturnTagSchema;

//# sourceMappingURL=return-tag.js.map