import { SchemaLocation, SchemaNode } from '../schema-node';
import { ParameterSchema } from './parameter';
import { DocSchema } from './docs';
export type Modifier = 'static' | 'public' | 'private' | 'protected' | 'readonly' | 'abstract' | 'async' | 'override' | 'export';
/**
 * function-like can be a function, method, arrow-function, variable-function, etc.
 */
export declare class FunctionLikeSchema extends SchemaNode {
    readonly location: SchemaLocation;
    readonly name: string;
    readonly modifiers: Modifier[];
    readonly typeParams?: string[] | undefined;
    readonly decorators?: SchemaNode[] | undefined;
    readonly returnType: SchemaNode;
    readonly params: ParameterSchema[];
    readonly doc?: DocSchema;
    readonly signature?: string | undefined;
    readonly displaySchemaName = "Functions";
    constructor(location: SchemaLocation, name: string, params: ParameterSchema[], returnType: SchemaNode, signature: string, modifiers?: Modifier[], doc?: DocSchema, typeParams?: string[] | undefined, decorators?: SchemaNode[] | undefined);
    getNodes(): (SchemaNode | ParameterSchema<SchemaNode>)[];
    toString(options?: {
        color?: boolean;
    }): string;
    toFullSignature(options?: {
        showDocs?: boolean;
    }): string;
    isDeprecated(): boolean;
    isPrivate(): boolean;
    generateSignature(): string;
    static createSignature(name: string, params: ParameterSchema[], returnType: SchemaNode, decorators?: SchemaNode[]): string;
    toObject(): {
        name: string;
        params: {
            name: string;
            type: Record<string, any>;
            isOptional: boolean;
            defaultValue: any;
            description: string | undefined;
            objectBindingNodes: Record<string, any>[] | undefined;
            isSpread: boolean;
        }[];
        returnType: Record<string, any>;
        signature: string | undefined;
        modifiers: Modifier[];
        doc: {
            __schema: string;
            name: string | undefined;
            location: SchemaLocation;
            signature: string | undefined;
            raw: string;
            comment: string | undefined;
            tags: {
                __schema: string;
                location: SchemaLocation;
                name: string | undefined;
                signature: string | undefined;
                tagName: string;
                comment: string | undefined;
            }[] | undefined;
        } | undefined;
        typeParams: string[] | undefined;
        decorators: Record<string, any>[] | undefined;
    };
    static fromObject(obj: Record<string, any>): FunctionLikeSchema;
    private modifiersToString;
}
