"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.InterfaceSchema = void 0;
function _chalk() {
  const data = _interopRequireDefault(require("chalk"));
  _chalk = function () {
    return data;
  };
  return data;
}
function _schemaNode() {
  const data = require("../schema-node");
  _schemaNode = function () {
    return data;
  };
  return data;
}
function _docs() {
  const data = require("./docs");
  _docs = function () {
    return data;
  };
  return data;
}
function _expressionWithArguments() {
  const data = require("./expression-with-arguments");
  _expressionWithArguments = function () {
    return data;
  };
  return data;
}
function _schemaRegistry() {
  const data = require("../schema-registry");
  _schemaRegistry = function () {
    return data;
  };
  return data;
}
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
class InterfaceSchema extends _schemaNode().SchemaNode {
  constructor(location, name, signature, extendsNodes, members, doc, typeParams) {
    super();
    this.location = location;
    this.name = name;
    this.signature = signature;
    this.extendsNodes = extendsNodes;
    this.typeParams = typeParams;
    this.members = members;
    this.doc = doc;
  }
  getNodes() {
    return this.members;
  }
  toString(options) {
    const boldUnderline = options?.color ? _chalk().default.bold.underline : str => str;
    const membersStr = this.members.map(m => `* ${m.toString(options)}`).join('\n');
    return `${boldUnderline(this.name)}\n${membersStr}`;
  }
  toFullSignature(options) {
    let result = '';
    if (options?.showDocs && this.doc) {
      result += `${this.doc.toFullSignature()}\n`;
    }
    let interfaceDeclaration = `interface ${this.name}`;
    if (this.typeParams && this.typeParams.length > 0) {
      interfaceDeclaration += `<${this.typeParams.join(', ')}>`;
    }
    if (this.extendsNodes && this.extendsNodes.length > 0) {
      const extendsStr = this.extendsNodes.map(node => node.toFullSignature(options)).join(', ');
      interfaceDeclaration += ` extends ${extendsStr}`;
    }
    result += `${interfaceDeclaration} {\n`;
    const membersStr = this.members.map(member => {
      const memberStr = member.toFullSignature(options);
      return memberStr.split('\n').map(line => `  ${line}`).join('\n');
    }).join('\n');
    result += `${membersStr}\n`;
    result += `}`;
    return result;
  }
  toObject() {
    return {
      ...super.toObject(),
      name: this.name,
      members: this.members.map(member => member.toObject()),
      doc: this.doc?.toObject(),
      signature: this.signature,
      extendsNodes: this.extendsNodes?.map(node => node.toObject()),
      typeParams: this.typeParams
    };
  }
  static fromObject(obj) {
    const location = obj.location;
    const name = obj.name;
    const signature = obj.signature;
    const extendsNodes = obj.extendsNodes?.map(node => _expressionWithArguments().ExpressionWithTypeArgumentsSchema.fromObject(node));
    const members = obj.members.map(member => _schemaRegistry().SchemaRegistry.fromObject(member));
    const doc = obj.doc ? _docs().DocSchema.fromObject(obj.doc) : undefined;
    const typeParams = obj.typeParams;
    return new InterfaceSchema(location, name, signature, extendsNodes, members, doc, typeParams);
  }
}
exports.InterfaceSchema = InterfaceSchema;

//# sourceMappingURL=interface.js.map