"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ParameterSchema = void 0;
function _schemaNode() {
  const data = require("../schema-node");
  _schemaNode = function () {
    return data;
  };
  return data;
}
function _schemaRegistry() {
  const data = require("../schema-registry");
  _schemaRegistry = function () {
    return data;
  };
  return data;
}
class ParameterSchema extends _schemaNode().SchemaNode {
  getNodes() {
    return [this.type, ...(this.objectBindingNodes || [])];
  }
  constructor(location, name, type, isOptional, defaultValue, description, objectBindingNodes, isSpread = false) {
    super();
    this.location = location;
    this.name = name;
    this.isOptional = isOptional;
    this.defaultValue = defaultValue;
    this.description = description;
    this.isSpread = isSpread;
    this.type = type;
    this.objectBindingNodes = objectBindingNodes;
  }
  toString() {
    return `${this.name}${this.isOptional ? '?' : ''}: ${this.type.toString()}`;
  }
  toFullSignature(options) {
    let paramStr = '';
    if (options?.showDocs && this.description) {
      paramStr += `/** ${this.description} */\n`;
    }
    if (this.isSpread) {
      paramStr += '...';
    }
    let paramName = '';
    if (this.objectBindingNodes && this.objectBindingNodes.length > 0) {
      const bindingsStr = this.objectBindingNodes.map(node => node.toFullSignature(options)).join(', ');
      paramName += `{ ${bindingsStr} }`;
    } else {
      paramName += this.name;
    }
    if (this.isOptional) {
      paramName += '?';
    }
    paramStr += `${paramName}`;
    if (this.type && typeof this.type.toString === 'function') {
      const typeName = this.type.toString();
      if (typeName) {
        paramStr += `: ${typeName}`;
      }
    }
    if (this.defaultValue !== undefined) {
      paramStr += ` = ${this.defaultValue}`;
    }
    return paramStr;
  }
  toObject() {
    return {
      ...super.toObject(),
      name: this.name,
      type: this.type.toObject(),
      isOptional: this.isOptional,
      defaultValue: this.defaultValue,
      description: this.description,
      objectBindingNodes: this.objectBindingNodes?.map(node => node.toObject()),
      isSpread: this.isSpread
    };
  }
  static fromObject(obj) {
    const location = obj.location;
    const name = obj.name;
    const type = _schemaRegistry().SchemaRegistry.fromObject(obj.type);
    const isOptional = obj.isOptional;
    const defaultValue = obj.defaultValue;
    const description = obj.description;
    const isSpread = obj.isSpread;
    const objectBindingNodes = obj.objectBindingNodes?.map(node => _schemaRegistry().SchemaRegistry.fromObject(node));
    return new ParameterSchema(location, name, type, isOptional, defaultValue, description, objectBindingNodes, isSpread);
  }
}
exports.ParameterSchema = ParameterSchema;

//# sourceMappingURL=parameter.js.map