"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.TypePredicateSchema = void 0;
function _schemaNode() {
  const data = require("../schema-node");
  _schemaNode = function () {
    return data;
  };
  return data;
}
function _schemaRegistry() {
  const data = require("../schema-registry");
  _schemaRegistry = function () {
    return data;
  };
  return data;
}
/**
 * e.g. `function f(str: any): str is string {}`
 *
 * example when the type is empty:
 * ```ts
 * function assert(condition: any, msg?: string): asserts condition {
 *  if (!condition) {
 *   throw new AssertionError(msg);
 *  }
 * }
 * ```
 *
 */
class TypePredicateSchema extends _schemaNode().SchemaNode {
  constructor(location, name, type, hasAssertsModifier = false) {
    super();
    this.location = location;
    this.name = name;
    this.hasAssertsModifier = hasAssertsModifier;
    this.type = type;
  }
  toString(options) {
    const assertsKeyword = this.hasAssertsModifier ? 'asserts ' : '';
    const typeStr = this.type ? ` is ${this.type.toString(options)}` : '';
    return assertsKeyword + this.name + typeStr;
  }
  toFullSignature(options) {
    const assertsKeyword = this.hasAssertsModifier ? 'asserts ' : '';
    const typeSignature = this.type ? ` is ${this.type.toFullSignature(options)}` : '';
    let signature = `${assertsKeyword}${this.name}${typeSignature}`;
    if (options?.showDocs && this.doc) {
      const docString = this.doc.toFullSignature();
      signature = `${docString}\n${signature}`;
    }
    return signature;
  }
  toObject() {
    return {
      ...super.toObject(),
      name: this.name,
      type: this.type?.toObject(),
      hasAssertsModifier: this.hasAssertsModifier
    };
  }
  static fromObject(obj) {
    const location = obj.location;
    const name = obj.name;
    const type = obj.type ? _schemaRegistry().SchemaRegistry.fromObject(obj.type) : undefined;
    const hasAssertsModifier = obj.hasAssertsModifier;
    return new TypePredicateSchema(location, name, type, hasAssertsModifier);
  }
}
exports.TypePredicateSchema = TypePredicateSchema;

//# sourceMappingURL=type-predicate.js.map