"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.TypeSchema = void 0;
function _chalk() {
  const data = _interopRequireDefault(require("chalk"));
  _chalk = function () {
    return data;
  };
  return data;
}
function _schemaNode() {
  const data = require("../schema-node");
  _schemaNode = function () {
    return data;
  };
  return data;
}
function _docs() {
  const data = require("./docs");
  _docs = function () {
    return data;
  };
  return data;
}
function _schemaRegistry() {
  const data = require("../schema-registry");
  _schemaRegistry = function () {
    return data;
  };
  return data;
}
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
class TypeSchema extends _schemaNode().SchemaNode {
  constructor(location, name, type, signature, doc) {
    super();
    this.location = location;
    this.name = name;
    this.signature = signature;
    this.type = type;
    this.doc = doc;
  }
  toString(options) {
    const bold = options?.color ? _chalk().default.bold : str => str;
    return `type ${bold(this.name)}: ${this.type.toString(options)}`;
  }
  toFullSignature(options) {
    const typeSignature = this.type.toFullSignature(options);
    let signature = `type ${this.name}: ${typeSignature}`;
    if (options?.showDocs && this.doc) {
      const docString = this.doc.toFullSignature();
      signature = `${docString}\n${signature}`;
    }
    return signature;
  }
  getNodes() {
    return [this.type];
  }
  toObject() {
    return {
      ...super.toObject(),
      name: this.name,
      type: this.type.toObject(),
      signature: this.signature
    };
  }
  static fromObject(obj) {
    const location = obj.location;
    const name = obj.name;
    const type = _schemaRegistry().SchemaRegistry.fromObject(obj.type);
    const signature = obj.signature;
    const doc = obj.doc ? _docs().DocSchema.fromObject(obj.doc) : undefined;
    return new TypeSchema(location, name, type, signature, doc);
  }
}
exports.TypeSchema = TypeSchema;

//# sourceMappingURL=type.js.map