"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.VariableLikeSchema = void 0;
function _chalk() {
  const data = _interopRequireDefault(require("chalk"));
  _chalk = function () {
    return data;
  };
  return data;
}
function _schemaNode() {
  const data = require("../schema-node");
  _schemaNode = function () {
    return data;
  };
  return data;
}
function _docs() {
  const data = require("./docs");
  _docs = function () {
    return data;
  };
  return data;
}
function _schemaRegistry() {
  const data = require("../schema-registry");
  _schemaRegistry = function () {
    return data;
  };
  return data;
}
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
/**
 * can be also a property or property-signature
 */
class VariableLikeSchema extends _schemaNode().SchemaNode {
  displaySchemaName = 'Variables';
  constructor(location, name, signature, type, isOptional, doc, defaultValue) {
    super();
    this.location = location;
    this.name = name;
    this.signature = signature;
    this.isOptional = isOptional;
    this.defaultValue = defaultValue;
    this.type = type;
    this.doc = doc;
  }
  getNodes() {
    return [this.type];
  }
  toString(options) {
    const bold = options?.color ? _chalk().default.bold : str => str;
    return `${bold(this.name)}${this.isOptional ? '?' : ''}: ${this.type.toString(options)}`;
  }
  toFullSignature(options) {
    const namePart = `${this.name}${this.isOptional ? '?' : ''}`;
    const typeSignature = this.type.toFullSignature(options);
    let signature = `${namePart}: ${typeSignature}`;
    if (this.defaultValue !== undefined) {
      signature += ` = ${this.defaultValue}`;
    }
    if (options?.showDocs && this.doc) {
      const docString = this.doc.toFullSignature();
      signature = `${docString}\n${signature}`;
    }
    return signature;
  }
  toObject() {
    return {
      ...super.toObject(),
      name: this.name,
      signature: this.signature,
      type: this.type.toObject(),
      isOptional: this.isOptional,
      doc: this.doc?.toObject(),
      defaultValue: this.defaultValue
    };
  }
  static fromObject(obj) {
    const location = obj.location;
    const name = obj.name;
    const signature = obj.signature;
    const type = _schemaRegistry().SchemaRegistry.fromObject(obj.type);
    const isOptional = obj.isOptional;
    const doc = obj.doc ? _docs().DocSchema.fromObject(obj.doc) : undefined;
    const defaultValue = obj.defaultValue;
    return new VariableLikeSchema(location, name, signature, type, isOptional, doc, defaultValue);
  }
}
exports.VariableLikeSchema = VariableLikeSchema;

//# sourceMappingURL=variable-like.js.map